<?php

/**
 * Webkul Software.
 *
 * @category  Webkul
 *
 * @author    Webkul Software Private Limited
 * @copyright Copyright (c) 2010-2017 Webkul Software Private Limited (https://webkul.com)
 * @license   https://store.webkul.com/license.html
 */

namespace Webkul\SalesforceConnector\Controller\Adminhtml\Orders;

use Webkul\SalesforceConnector\Helper\Order;

class Ordersync extends \Magento\Backend\App\Action
{
    /** @var \Magento\Framework\View\Result\PageFactory */
    protected $_resultPageFactory;
    // protected $_categoryCollection;
    /**
     * Massactions filter.
     *
     * @var Filter
     */
    protected $_filter;

    /**
     * @var CollectionFactory
     */
    protected $_collectionFactory;
    protected $_helper;
    protected $_helperData;

    /**
     * @param \Magento\Backend\App\Action\Context        $context
     * @param \Magento\Framework\View\Result\PageFactory $resultPageFactory
     */
    public function __construct(
        \Magento\Backend\App\Action\Context $context,
        \Magento\Framework\View\Result\PageFactory $resultPageFactory,
        \Magento\Ui\Component\MassAction\Filter $filter,
        \Magento\Sales\Model\ResourceModel\Order\CollectionFactory $collectionFactory,
        Order $helper
    ) {
        parent::__construct($context);
        $this->_resultPageFactory = $resultPageFactory;
        $this->_helper = $helper;
        $this->_filter = $filter;
        $this->_collectionFactory = $collectionFactory;
    }

    public function execute()
    {
        if (\Webkul\SalesforceConnector\Helper\Connection::checkConnectionStatus()) {
            $id = $this->getRequest()->getParam('entity_id');
            if ($id) {
                $sfId = $this->_helper->syncSpecificOrder($id);
                if (isset($sfId['error'])) {
                    $this->messageManager
                        ->addError(__($sfId['error']));
                }
                elseif($sfId){                    
                    $this->messageManager
                        ->addSuccess(__('Order has been successfully Exported at Salesforce.', $sfId));       
                }
                else {
                    $this->messageManager
                        ->addError(__('Order has not been Exported at Salesforce.'));
                }
            } else {
                $success=0;
                $ids = $this->getRequest()->getParam('selected');

                if ($ids) {
                    $exportData = $this->_helper->syncBulkOrders($ids);
                    if(isset($exportData['error'])){
                        $this->messageManager
                        ->addError(__($exportData['error']));
                    }
                    $success += $exportData[0];
                    $this->messageManager->addSuccess(
                        __('A total of %1 record(s) have been processed.', $success)
                    );
                } else {
                    $excludedIds = $this->getRequest()->getParam('excluded');
                    $collection = $this->_collectionFactory->create();
                    $allOrderIds = array();
                    foreach ($collection->getItems() as $item) {
                        array_push($allOrderIds, $item->getID());
                    }
                    if ($excludedIds == 'false') {
                        $exportData = $this->_helper->syncBulkOrders($allOrderIds);
                        if(isset($exportData['error'])){
                            $this->messageManager
                            ->addError(__($exportData['error']));
                        }
                        $success += $exportData[0];
                        $this->messageManager->addSuccess(
                            __('A total of %1 record(s) have been processed.', $success)
                        );
                    } else {
                        $id = array_diff($allOrderIds, $excludedIds);
                        $exportData = $this->_helper->syncBulkOrders($id);
                        if(isset($exportData['error'])){
                            $this->messageManager
                            ->addError(__($exportData['error']));
                        }
                        $this->messageManager->addSuccess(
                            __('A total of %1 record(s) have been processed.', $success)
                        );
                    }
                }
            }
        } else {
            $this->messageManager
                ->addError(__('Check Connection'));
        }
        $resultRedirect = $this->resultRedirectFactory->create();
        $resultRedirect->setPath('sfconnector/orders/index/');

        return $resultRedirect;
    }
}
