<?php
/**
 * Webkul Software.
 *
 * @category  Webkul
 * @package   Webkul_Eshopsync
 * @author    Webkul Software Private Limited
 * @copyright Copyright (c) 2010-2017 Webkul Software Private Limited (https://webkul.com)
 * @license   https://store.webkul.com/license.html
 */

namespace Webkul\SalesforceConnector\Observer;
 
use Magento\Framework\Event\ObserverInterface;
use Magento\Framework\Event\Observer;
use Magento\Framework\App\RequestInterface;

class AfterAdminOrderPlace implements ObserverInterface
{
 
    /** @var \Magento\Framework\Logger\Monolog */
    protected $_logger;

    /** @var \Webkul\Eshopsync\Helper\Connection */
    protected $_helperConnection;
    protected $_helperData;

    /** @var \Webkul\Eshopsync\Helper\Order */
    protected $_helperOrder;

    /** @var Magento\Framework\App\RequestInterface */
    protected $_request;

    /** @var \Webkul\Eshopsync\Model\CategoryFactory */
    protected $_eshopsyncCategory;

    /** @var \Magento\Catalog\Model\CategoryFactory */
    protected $_catalogCategory;

    /**
     * @param \Psr\Log\LoggerInterface                   $loggerInterface
     * @param \Webkul\Eshopsync\Helper\Connection        $helperConnection
     * @param \Webkul\Eshopsync\Helper\Order             $helperOrder
     * @param RequestInterface                           $requestInterface
     * @param \Webkul\Eshopsync\Model\CategoryFactory    $eshopsyncCategory
     * @param \Magento\Catalog\Model\CategoryFactory     $catalogCategory
     */
    public function __construct(
        \Psr\Log\LoggerInterface $loggerInterface,
        \Webkul\SalesforceConnector\Helper\Connection $helperConnection,
        \Webkul\SalesforceConnector\Helper\Data $helperData,
        \Webkul\SalesforceConnector\Helper\Order $helperOrder,
        RequestInterface $requestInterface,
        \Webkul\SalesforceConnector\Model\CategoryFactory $eshopsyncCategory,
        \Magento\Catalog\Model\CategoryFactory $catalogCategory
    ) {
    
        $this->_logger = $loggerInterface;
        $this->_helperConnection = $helperConnection;
        $this->_helperData = $helperData;
        $this->_helperOrder = $helperOrder;
        $this->_request = $requestInterface;
        $this->_eshopsyncCategory = $eshopsyncCategory;
        $this->_catalogCategory = $catalogCategory;
    }
    /**
     * This is the method that fires when the event runs.
     *
     * @param Observer $observer
     */

    public function execute(Observer $observer)
    {
        $orderSync = $this->_helperData->getConfigValue('autoSync', 'autoSyncOrderSync');
        if ($orderSync) {
            $lastOrderId = $observer->getOrder()->getId();
            if (!$lastOrderId) {
                return;
            }
            
            /***************** Order Synchronization  *********************/
            $this->_helperOrder->syncSpecificOrder($lastOrderId);
            
        }
    }
}
